#region Copyright Syncfusion Inc. 2001-2019.
// Copyright Syncfusion Inc. 2001-2019. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.UI.Xaml.Diagram;
using Syncfusion.UI.Xaml.Diagram.Layout;
using Syncfusion.Windows.Shared;
using System;

using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Xml.Linq;

namespace AutomaticLayout_OrganizationLayout
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            sfdiagram.Constraints = GraphConstraints.Default & ~(GraphConstraints.PanRails | GraphConstraints.PageEditing);
            sfdiagram.Menu = null;
            sfdiagram.Tool = Tool.ZoomPan;
            sfdiagram.DefaultConnectorType = ConnectorType.Orthogonal;


            // Initialize DataSourceSettings for SfDiagram

            sfdiagram.DataSourceSettings = new DataSourceSettings()
            {
                ParentId = "ReportingPerson",
                Id = "Name",
                DataSource = Getdata(),
            };

            // Initialize LayoutSettings for SfDiagram

            sfdiagram.LayoutManager = new LayoutManager()
            {
                Layout = new DirectedTreeLayout()
                {
                    Type = LayoutType.Organization,
                    HorizontalSpacing = 50,
                    VerticalSpacing = 40,
                    Orientation = TreeOrientation.TopToBottom,
                },                
            };

            sfdiagram.LayoutManager.Layout.UpdateLayout();
        }
        private Employees Getdata()
        {
            Employees employee = new Employees();

            employee.Add(new Employee()
            {
                Name = "Maria Anders",

                Designation = "Managing Director",
                ImageUrl = "./Assets/eric.png",
                RatingColor = "#71AF17",

            });

            employee.Add(new Employee()
            {
                Name = "Pedro Afonso",
                Designation = "Project Manager",
                ImageUrl = "./Assets/Paul.png",
                RatingColor = "#1859B7",
                ReportingPerson = "Maria Anders"
            });

            employee.Add(new Employee()
            {
                Name = "Elizabeth Brown",
                Designation = "Project Lead",
                ImageUrl = "./Assets/Maria.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Pedro Afonso"
            });

            employee.Add(new Employee()
            {
                Name = "Aria Cruz",
                Designation = "Project Lead",
                ImageUrl = "./Assets/Jenny.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Pedro Afonso"
            });

            employee.Add(new Employee()
            {
                Name = "Martn Sommer",
                Designation = "Senior S/w Engg",
                ImageUrl = "./Assets/image2.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Pedro Afonso"
            });

            employee.Add(new Employee()
            {
                Name = "Jaime Yorres",
                Designation = "S/w Engg",
                ImageUrl = "./Assets/image2.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Pedro Afonso"
            });

            employee.Add(
                new Employee
                {
                    Name = "John Steel",
                    Designation = "Project Trainee",
                    ImageUrl = "/Assets/Maria.png",
                    RatingColor = "#2E95D8",
                    ReportingPerson = "Pedro Afonso"
                });

            employee.Add(new Employee()
            {
                Name = "Lino Rodriguez",
                Designation = "Project Manager",
                ImageUrl = "./Assets/Robin.PNG",
                RatingColor = "#1859B7",
                ReportingPerson = "Maria Anders"
            });

            employee.Add(new Employee()
            {
                Name = "Hanna Moos",
                Designation = "Project Lead",
                ImageUrl = "./Assets/image55.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Lino Rodriguez"
            });

            employee.Add(new Employee()
            {
                Name = "Howard Snyder",
                Designation = "Project Lead",
                ImageUrl = "./Assets/image12.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Lino Rodriguez"
            });


            employee.Add(new Employee()
            {
                Name = "Philip Cramer",
                Designation = "Project Manager",
                ImageUrl = "./Assets/image2.PNG",
                RatingColor = "#1859B7",
                ReportingPerson = "Maria Anders"
            });

            employee.Add(new Employee()
            {
                Name = "Daniel Tonini",
                Designation = "Project Lead",
                ImageUrl = "./Assets/image57.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Philip Cramer"
            });

            employee.Add(new Employee()
            {
                Name = "Annette Roulet",
                Designation = "Senior S/w Engg",
                ImageUrl = "./Assets/image55.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Philip Cramer"
            });

            employee.Add(new Employee()
            {
                Name = "Yoshi Tannamuri",
                Designation = "S/w Engg",
                ImageUrl = "./Assets/image57.png",
                RatingColor = "#2E95D8",
                ReportingPerson = "Philip Cramer"
            });

            return employee;
        }
    }

    public class Employee : INotifyPropertyChanged
    {
        private string name;
        private string imageurl;
        private string heatmap = "#FFC34444";
        private string reportingPerson;

        public Employee()
        {
            Models = new ObservableCollection<Employee>();
        }

        private string _mDesignation;
        public string Designation
        {
            get { return _mDesignation; }
            set
            {
                if (_mDesignation != value)
                {
                    _mDesignation = value;
                    OnPropertyChanged("Designation");
                }
            }
        }


        private SolidColorBrush ColorConverter(string hexaColor)
        {
            if (hexaColor != null)
            {
                byte r = Convert.ToByte(hexaColor.Substring(1, 2), 16);
                byte g = Convert.ToByte(hexaColor.Substring(3, 2), 16);
                byte b = Convert.ToByte(hexaColor.Substring(5, 2), 16);
                byte a = Convert.ToByte(hexaColor.Substring(7, 2), 16);
                SolidColorBrush myBrush = new SolidColorBrush(Color.FromArgb(r, g, b, a));
                return myBrush;
            }
            return null;
        }


        public string Name
        {
            get
            {
                return name;
            }
            set
            {
                if (name != value)
                {
                    name = value;
                    OnPropertyChanged(("Name"));
                }
            }
        }

        public string ReportingPerson
        {
            get
            {
                return reportingPerson;
            }
            set
            {
                if (reportingPerson != value)
                {
                    reportingPerson = value;
                    OnPropertyChanged(("ReportingPerson"));
                }
            }
        }

        public string ImageUrl
        {
            get
            {
                return imageurl;
            }
            set
            {
                if (imageurl != value)
                {
                    if (value != null)
                    {
                        imageurl = value;
                        OnPropertyChanged(("ImageUrl"));
                    }
                }
            }
        }


        public string RatingColor
        {
            get
            {
                return heatmap;
            }
            set
            {
                if (heatmap != value)
                {
                    if (value != null)
                    {
                        heatmap = value;
                        OnPropertyChanged(("RatingColor"));
                    }
                }
            }
        }

        private ObservableCollection<Employee> models;

        public ObservableCollection<Employee> Models
        {
            get { return models; }
            set
            {
                models = value;                
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string name)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged.Invoke(this, new PropertyChangedEventArgs(name));
            }
        }
    }

    public class Employees : ObservableCollection<Employee>
    {

    }
}
